@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.0.1"
+__version__ = "2.0.2"
 __all__ = ['Model', 'Wizard']
 from types import NoneType
 import threading
@@ -462,7 +462,7 @@ class Model(object):
     _config = None
     _fields = None
 
-    def __init__(self, id=None, **kwargs):
+    def __init__(self, id=None, _default=True, **kwargs):
         super(Model, self).__init__()
         if id:
             assert not kwargs
@@ -474,7 +474,7 @@ class Model(object):
         self._parent = None # store the parent record
         self._parent_field_name = '' # store the field name in parent record
         self._parent_name = '' # store the field name to parent record
-        if self.id < 0:
+        if self.id < 0 and _default:
             self._default_get()
 
         for field_name, value in kwargs.iteritems():
@@ -667,11 +667,8 @@ class Model(object):
         return res
 
     def _on_change_set(self, field, value):
-        if self._fields[field]['type'] in ('one2many', 'many2many'):
-            if isinstance(value, (list, tuple)):
-                self._values[field] = value
-                self._changed.add(field)
-                return
+        if (self._fields[field]['type'] in ('one2many', 'many2many')
+                and not isinstance(value, (list, tuple))):
             to_remove = []
             if value and value.get('remove'):
                 for record_id in value['remove']:
@@ -685,8 +682,10 @@ class Model(object):
                 for vals in value.get('add', []):
                     relation = Model.get(self._fields[field]['relation'],
                             self._config)
-                    record = relation()
+                    record = relation(_default=False)
                     for i, j in vals.iteritems():
+                        if '.' in i:
+                            continue
                         record._values[i] = j
                         record._changed.add(i)
                     # append without signal
@@ -697,11 +696,13 @@ class Model(object):
                     for record in getattr(self, field):
                         if record.id == vals['id']:
                             for i, j in vals.iteritems():
+                                if '.' in i:
+                                    continue
                                 record._values[i] = j
                                 record._changed.add(i)
         else:
             self._values[field] = value
-            self._changed.add(field)
+        self._changed.add(field)
 
     def _on_change(self, name):
         'Call on_change for field'
